@@ -212,6 +212,54 @@ def test_trigger_single(
         env_vars={
             "AUTORELEASE_PR": "https://github.com/googleapis/java-trace/pull/1234"
         },
+        multi_scm_name="",
+    )
+    update_pull_labels.assert_not_called()
+
+
+@patch("autorelease.trigger.LANGUAGE_ALLOWLIST", ["java"])
+@patch("autorelease.kokoro.make_authorized_session")
+@patch("autorelease.github.GitHub.get_issue")
+@patch("autorelease.github.GitHub.get_url")
+@patch("autorelease.github.GitHub.update_pull_labels")
+@patch("autorelease.kokoro.trigger_build")
+def test_trigger_single_multi_scm(
+    trigger_build, update_pull_labels, get_url, get_issue, make_authorized_session
+):
+    kokoro_session = Mock()
+    make_authorized_session.return_value = kokoro_session
+    get_issue.return_value = {
+        "title": "chore: release 1.2.3",
+        "pull_request": {
+            "html_url": "https://github.com/googleapis/java-trace/pull/1234",
+            "url": "https://api.github.com/repos/googleapis/java-trace/pulls/1234",
+        },
+    }
+    get_url.return_value = {
+        "merged_at": "2021-07-20T09:00:00.123Z",
+        "base": {"repo": {"full_name": "googleapis/java-trace"}},
+        "html_url": "https://github.com/googleapis/java-trace/pull/1234",
+        "merge_commit_sha": "abcd1234",
+        "labels": [{"id": 12345, "name": "autorelease: tagged"}],
+    }
+
+    pull_request_url = "https://github.com/googleapis/java-trace/pull/1234"
+    reporter = trigger.trigger_single(
+        "fake-github-token",
+        "fake-kokoro-credentials",
+        pull_request_url,
+        multi_scm_name="java-trace",
+    )
+
+    assert len(reporter.results) == 1
+    trigger_build.assert_called_with(
+        kokoro_session,
+        job_name="cloud-devrel/client-libraries/java/java-trace/release/stage",
+        sha="abcd1234",
+        env_vars={
+            "AUTORELEASE_PR": "https://github.com/googleapis/java-trace/pull/1234"
+        },
+        multi_scm_name="java-trace",
     )
     update_pull_labels.assert_not_called()
 
@@ -250,6 +298,7 @@ def test_trigger_package(
         env_vars={
             "AUTORELEASE_PR": "https://github.com/GoogleCloudPlatform/functions-framework-java/pull/111"
         },
+        multi_scm_name="",
     )
 
 
@@ -303,3 +352,43 @@ def test_trigger_single_skips_already_triggered(
 
     assert len(reporter.results) == 1
     trigger_build.assert_not_called()
+
+
+@patch("autorelease.trigger.LANGUAGE_ALLOWLIST", ["java"])
+@patch("autorelease.kokoro.make_authorized_session")
+@patch("autorelease.github.GitHub.get_issue")
+@patch("autorelease.github.GitHub.get_url")
+@patch("autorelease.github.GitHub.update_pull_labels")
+@patch("autorelease.kokoro.trigger_build")
+def test_trigger_multi_scm(
+    trigger_build, update_pull_labels, get_url, get_issue, make_authorized_session
+):
+    github = Mock()
+    kokoro_session = Mock()
+    github.get_url.return_value = {
+        "merged_at": "2021-01-01T09:00:00.000Z",
+        "base": {"repo": {"full_name": "GoogleCloudPlatform/functions-framework-java"}},
+        "html_url": "https://github.com/GoogleCloudPlatform/functions-framework-java/pull/111",
+        "labels": [{"id": 111, "name": "autorelease: tagged"}],
+        "merge_commit_sha": "abcd111",
+        "title": "chore(master): release java-function-invoker 1.1.2",
+    }
+    issue = {
+        "pull_request": {
+            "url": "https://api.github.com/repos/GoogleCloudPlatform/functions-framework-java/pulls/111"
+        },
+        "merged_at": "2021-01-01T09:00:00.000Z",
+    }
+
+    trigger.trigger_kokoro_build_for_pull_request(
+        kokoro_session, github, issue, Mock(), multi_scm_name="functions-framework-java"
+    )
+    trigger_build.assert_called_with(
+        kokoro_session,
+        job_name="functions-framework/java/java-function-invoker/release",
+        sha="abcd111",
+        env_vars={
+            "AUTORELEASE_PR": "https://github.com/GoogleCloudPlatform/functions-framework-java/pull/111"
+        },
+        multi_scm_name="functions-framework-java",
+    )
